@@ -5,6 +5,7 @@ from networktools.colorprint import gprint, bprint, rprint
 
 from .taskloop import coromask, renew, simple_fargs, simple_fargs_out
 from .scheduler import TaskScheduler
+from .taskloop import TaskLoop
 
 
 def get_free_ico(icos):
@@ -137,23 +138,11 @@ class TaskAssignator:
         asyncio.set_event_loop(loop)
         try:
             args = [self.queue_tasks]
-            bprint("New process task")
-            task = loop.create_task(
-                coromask(
-                    self.new_process,
-                    args, {},
-                    simple_fargs_out))
-            #
-            task.add_done_callback(
-                functools.partial(
-                    renew,
-                    task,
-                    self.new_process,
-                    simple_fargs_out)
-            )
-            print(f"Msg managaer task {task}")
+            task = TaskLoop(self.new_process, args, {},
+                            {"name": "task_assignator"})
+            task.create()
             if not loop.is_running():
-                loop.run_until_complete(asyncio.gather(task))
+                loop.run_forever()
         except Exception as ex:
             rprint("Error en levantar corrutina %s" % ex)
             raise ex
