@@ -152,7 +152,7 @@ class TaskLoop:
         self.time_pause = kwargs.get('time_pause', .1)
 
     def __str__(self):
-        return f'''Taskllop {self.name},
+        return f'''Taskloop {self.name},
         coro {self.coro}, args {self.coro_args},
         kwargs {self.coro_kwargs}'''
 
